@@ -1,8 +1,8 @@
 # Paranoid -- Paranoia support for safer programs
 #
-# (c) 2005, Arthur Corliss <corliss@digitalmages.com>
+# (c) 2005 - 2017, Arthur Corliss <corliss@digitalmages.com>
 #
-# $Id: Paranoid.pm,v 0.34 2012/05/29 21:40:51 acorliss Exp $
+# $Id: lib/Paranoid.pm, 2.05 2017/02/06 01:48:57 acorliss Exp $
 #
 #    This software is licensed under the same terms as Perl, itself.
 #    Please see http://dev.perl.org/licenses/ for more information.
@@ -17,18 +17,20 @@
 
 package Paranoid;
 
-use 5.006;
+use 5.008;
 
 use strict;
 use warnings;
 use vars qw($VERSION @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use base qw(Exporter);
 
-($VERSION) = ( q$Revision: 0.34 $ =~ /(\d+(?:\.(\d+))+)/sm );
+($VERSION) = ( q$Revision: 2.05 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 @EXPORT      = qw(psecureEnv);
-@EXPORT_OK   = qw(psecureEnv);
-%EXPORT_TAGS = ( all => [qw(psecureEnv)], );
+@EXPORT_OK   = ( @EXPORT, qw(PTRUE_ZERO) );
+%EXPORT_TAGS = ( all => [@EXPORT_OK], );
+
+use constant PTRUE_ZERO => '0 but true';
 
 #####################################################################
 #
@@ -64,7 +66,7 @@ sub psecureEnv (;$) {
     delete @ENV{qw(IFS CDPATH ENV BASH_ENV)};
     $ENV{PATH} = $path;
     if ( exists $ENV{TERM} ) {
-        if ( $ENV{TERM} =~ /^([\w\+\.\-]+)$/sm ) {
+        if ( $ENV{TERM} =~ /^([\w\+\.\-]+)$/s ) {
             $ENV{TERM} = $1;
         } else {
             $ENV{TERM} = 'vt100';
@@ -98,7 +100,7 @@ Paranoid - Paranoia support for safer programs
 
 =head1 VERSION
 
-$Id: Paranoid.pm,v 0.34 2012/05/29 21:40:51 acorliss Exp $
+$Id: lib/Paranoid.pm, 2.05 2017/02/06 01:48:57 acorliss Exp $
 
 =head1 SYNOPSIS
 
@@ -175,11 +177,6 @@ L<Paranoid::Args>: Command-line argument parsing functions
 
 =item o
 
-L<Paranoid::BerkeleyDB>: OO-oriented BerkelyDB access with concurrent access
-capabilities
-
-=item o
-
 L<Paranoid::Data>: Misc. data manipulation functions
 
 =item o
@@ -196,15 +193,31 @@ L<Paranoid::Glob>: Paranoid Glob objects
 
 =item o
 
+L<Paranoid::IO>: File I/O wrappers for sysopen, etc.
+
+=item o
+
+L<Paranoid::IO::Line>: I/O functions for working with line-based files
+
+=item o
+
+L<Paranoid::IO::Lockfile>: I/O functions for working with lock files
+
+=item o
+
 L<Paranoid::Input>: Input-related functions (file reading, detainting)
 
 =item o
 
-L<Paranoid::Lockfile>: Lockfile support
+L<Paranoid::Log>: Unified logging framework and functions
 
 =item o
 
-L<Paranoid::Log>: Unified logging framework and functions
+L<Paranoid::Log::Buffer>: Buffered-based logging mechanism
+
+=item o
+
+L<Paranoid::Log::File>: File-based logging mechanism
 
 =item o
 
@@ -234,11 +247,6 @@ L<Paranoid::Process>: Process management functions
 
 =head1 BUGS AND LIMITATIONS
 
-If your application is sensitive to performance issues then you may
-be better off not using these modules.  The primary focus was on security,
-robustness, and diagnostics.  That said, there's probably a lot of room for
-improvement on the performance front.
-
 =head1 AUTHOR
 
 Arthur Corliss (corliss@digitalmages.com)
@@ -248,5 +256,5 @@ Arthur Corliss (corliss@digitalmages.com)
 This software is licensed under the same terms as Perl, itself. 
 Please see http://dev.perl.org/licenses/ for more information.
 
-(c) 2005, Arthur Corliss (corliss@digitalmages.com)
+(c) 2005 - 2017, Arthur Corliss (corliss@digitalmages.com)
 
