@@ -1,8 +1,8 @@
 # Paranoid::Filesystem -- Filesystem support for paranoid programs
 #
-# (c) 2005 - 2015, Arthur Corliss <corliss@digitalmages.com>
+# (c) 2005 - 2017, Arthur Corliss <corliss@digitalmages.com>
 #
-# $Id: lib/Paranoid/Filesystem.pm, 2.04 2016/09/19 15:00:25 acorliss Exp $
+# $Id: lib/Paranoid/Filesystem.pm, 2.05 2017/02/06 01:48:57 acorliss Exp $
 #
 #    This software is licensed under the same terms as Perl, itself.
 #    Please see http://dev.perl.org/licenses/ for more information.
@@ -33,7 +33,7 @@ use Paranoid::Input;
 use Paranoid::IO;
 use Paranoid::Glob;
 
-($VERSION) = ( q$Revision: 2.04 $ =~ /(\d+(?:\.\d+)+)/sm );
+($VERSION) = ( q$Revision: 2.05 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 @EXPORT = qw(
     preadDir     psubdirs    pfiles
@@ -69,7 +69,7 @@ sub pmkdir ($;$\%) {
     my $path = shift;
     my $mode = shift;
     my $eref = shift || {};
-    my ( $dirs, $directory, @parts, $i );
+    my ( $dirs, $directory, $subdir, @parts, $i );
     my $rv = 1;
 
     pdebug( 'entering w/(%s)(%s)', PDLEVEL1, $path, $mode );
@@ -112,11 +112,12 @@ sub pmkdir ($;$\%) {
             $i = $parts[0] eq '' ? 1 : 0;
             $i++ while $i < $#parts and -d join '/', @parts[ 0 .. $i ];
             while ( $i <= $#parts ) {
-                unless ( mkdir join( '/', @parts[ 0 .. $i ] ), $mode ) {
+                $subdir = join '/', @parts[ 0 .. $i ];
+                unless ( -d $subdir or mkdir $subdir, $mode ) {
 
                     # Error out and halt all work
                     Paranoid::ERROR = pdebug( 'failed to create %s: %s',
-                        PDLEVEL1, $directory, $! );
+                        PDLEVEL1, $subdir, $! );
                     $rv = 0;
                     last;
                 }
@@ -1035,7 +1036,7 @@ Paranoid::Filesystem - Filesystem Functions
 
 =head1 VERSION
 
-$Id: lib/Paranoid/Filesystem.pm, 2.04 2016/09/19 15:00:25 acorliss Exp $
+$Id: lib/Paranoid/Filesystem.pm, 2.05 2017/02/06 01:48:57 acorliss Exp $
 
 =head1 SYNOPSIS
 
@@ -1389,5 +1390,5 @@ Arthur Corliss (corliss@digitalmages.com)
 This software is licensed under the same terms as Perl, itself. 
 Please see http://dev.perl.org/licenses/ for more information.
 
-(c) 2005 - 2015, Arthur Corliss (corliss@digitalmages.com)
+(c) 2005 - 2017, Arthur Corliss (corliss@digitalmages.com)
 
