@@ -1,8 +1,8 @@
 # Paranoid::IO -- Paranoid IO support
 #
-# (c) 2005 - 2015, Arthur Corliss <corliss@digitalmages.com>
+# (c) 2005 - 2017, Arthur Corliss <corliss@digitalmages.com>
 #
-# $Id: lib/Paranoid/IO.pm, 2.04 2016/09/19 15:00:25 acorliss Exp $
+# $Id: lib/Paranoid/IO.pm, 2.05 2017/02/06 01:48:57 acorliss Exp $
 #
 #    This software is licensed under the same terms as Perl, itself.
 #    Please see http://dev.perl.org/licenses/ for more information.
@@ -30,7 +30,7 @@ use Paranoid::Debug qw(:all);
 use Paranoid::Input;
 use IO::Handle;
 
-($VERSION) = ( q$Revision: 2.04 $ =~ /(\d+(?:\.\d+)+)/sm );
+($VERSION) = ( q$Revision: 2.05 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 @EXPORT = qw(pclose pcloseAll popen preopen ptell pseek pflock pread
     pnlread pwrite pappend ptruncate);
@@ -274,6 +274,7 @@ use constant PDEFFILESZ => 65536;
             $af = $fh->autoflush;
 
             # Close the old file handle
+            $tmp{fh} = $fh = undef;
             if ( pclose($filename) ) {
 
                 # Remove O_TRUNC
@@ -290,7 +291,7 @@ use constant PDEFFILESZ => 65536;
 
                     # Move the record over to the original file name
                     $files{$filename} = { %{ $files{ $tmp{real} } } };
-                    delete $files{ $tmp{real} };
+                    delete $files{ $tmp{real} } if $filename ne $tmp{real};
                 }
             }
         }
@@ -751,7 +752,7 @@ Paranoid::IO - Paranoid IO support
 
 =head1 VERSION
 
-$Id: lib/Paranoid/IO.pm, 2.04 2016/09/19 15:00:25 acorliss Exp $
+$Id: lib/Paranoid/IO.pm, 2.05 2017/02/06 01:48:57 acorliss Exp $
 
 =head1 SYNOPSIS
 
@@ -1117,5 +1118,5 @@ Arthur Corliss (corliss@digitalmages.com)
 This software is licensed under the same terms as Perl, itself. 
 Please see http://dev.perl.org/licenses/ for more information.
 
-(c) 2005 - 2015, Arthur Corliss (corliss@digitalmages.com)
+(c) 2005 - 2017, Arthur Corliss (corliss@digitalmages.com)
 
