@@ -1,8 +1,8 @@
 # Paranoid::Process -- Process management support for paranoid programs
 #
-# (c) 2005 - 2016, Arthur Corliss <corliss@digitalmages.com>
+# (c) 2005 - 2017, Arthur Corliss <corliss@digitalmages.com>
 #
-# $Id: lib/Paranoid/Process.pm, 2.04 2016/09/19 15:00:25 acorliss Exp $
+# $Id: lib/Paranoid/Process.pm, 2.05 2017/02/06 01:48:57 acorliss Exp $
 #
 #    This software is licensed under the same terms as Perl, itself.
 #    Please see http://dev.perl.org/licenses/ for more information.
@@ -28,7 +28,7 @@ use Paranoid::Debug qw(:all);
 use POSIX qw(getuid setuid setgid WNOHANG setsid);
 use Carp;
 
-($VERSION) = ( q$Revision: 2.04 $ =~ /(\d+(?:\.\d+)+)/sm );
+($VERSION) = ( q$Revision: 2.05 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 @EXPORT    = qw(switchUser daemonize);
 @EXPORT_OK = (
@@ -226,7 +226,7 @@ sub sigchld {
     my $sref = _chldHandler();
 
     # Remove the signal handler so we're not preempted
-    local $SIG{CHLD} = 'IGNORE';
+    local $SIG{CHLD} = sub { 1 };
 
     # Process children exit values
     do {
@@ -234,6 +234,7 @@ sub sigchld {
         if ( $pid > 0 ) {
             _decrChildren();
             pdebug( 'child %d reaped w/rv: %s', PDLEVEL1, $pid, $? );
+            pdebug( 'children remaining: %s', PDLEVEL1, childrenCount());
 
             # Call the user's sig handler if defined
             &$sref( $pid, $? ) if defined $sref;
@@ -524,7 +525,7 @@ Paranoid::Process - Process Management Functions
 
 =head1 VERSION
 
-$Id: lib/Paranoid/Process.pm, 2.04 2016/09/19 15:00:25 acorliss Exp $
+$Id: lib/Paranoid/Process.pm, 2.05 2017/02/06 01:48:57 acorliss Exp $
 
 =head1 SYNOPSIS
 
@@ -771,5 +772,5 @@ Arthur Corliss (corliss@digitalmages.com)
 This software is licensed under the same terms as Perl, itself. 
 Please see http://dev.perl.org/licenses/ for more information.
 
-(c) 2005 - 2016, Arthur Corliss (corliss@digitalmages.com)
+(c) 2005 - 2017, Arthur Corliss (corliss@digitalmages.com)
 
